@@ -14,5 +14,5 @@ qpq <- function(x, y) {
         stop("Cannot happen!")
     }
 
-    .Call("qoq", x, y, as.integer(1), PACKAGE = "rcdd")
+    .Call(C_qoq, x, y, as.integer(1))
 }
